# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from generated.sikuli.v1 import sikuli_pb2 as sikuli_dot_v1_dot_sikuli__pb2


class SikuliServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Find = channel.unary_unary(
                '/sikuli.v1.SikuliService/Find',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindResponse.FromString,
                _registered_method=True)
        self.FindAll = channel.unary_unary(
                '/sikuli.v1.SikuliService/FindAll',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindAllResponse.FromString,
                _registered_method=True)
        self.FindOnScreen = channel.unary_unary(
                '/sikuli.v1.SikuliService/FindOnScreen',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindOnScreenRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindResponse.FromString,
                _registered_method=True)
        self.ExistsOnScreen = channel.unary_unary(
                '/sikuli.v1.SikuliService/ExistsOnScreen',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.ExistsOnScreenRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ExistsOnScreenResponse.FromString,
                _registered_method=True)
        self.WaitOnScreen = channel.unary_unary(
                '/sikuli.v1.SikuliService/WaitOnScreen',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.WaitOnScreenRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindResponse.FromString,
                _registered_method=True)
        self.ClickOnScreen = channel.unary_unary(
                '/sikuli.v1.SikuliService/ClickOnScreen',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.ClickOnScreenRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindResponse.FromString,
                _registered_method=True)
        self.ReadText = channel.unary_unary(
                '/sikuli.v1.SikuliService/ReadText',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.ReadTextRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ReadTextResponse.FromString,
                _registered_method=True)
        self.FindText = channel.unary_unary(
                '/sikuli.v1.SikuliService/FindText',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindTextRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindTextResponse.FromString,
                _registered_method=True)
        self.MoveMouse = channel.unary_unary(
                '/sikuli.v1.SikuliService/MoveMouse',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.MoveMouseRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
                _registered_method=True)
        self.Click = channel.unary_unary(
                '/sikuli.v1.SikuliService/Click',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.ClickRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
                _registered_method=True)
        self.TypeText = channel.unary_unary(
                '/sikuli.v1.SikuliService/TypeText',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.TypeTextRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
                _registered_method=True)
        self.Hotkey = channel.unary_unary(
                '/sikuli.v1.SikuliService/Hotkey',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.HotkeyRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
                _registered_method=True)
        self.ObserveAppear = channel.unary_unary(
                '/sikuli.v1.SikuliService/ObserveAppear',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveResponse.FromString,
                _registered_method=True)
        self.ObserveVanish = channel.unary_unary(
                '/sikuli.v1.SikuliService/ObserveVanish',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveResponse.FromString,
                _registered_method=True)
        self.ObserveChange = channel.unary_unary(
                '/sikuli.v1.SikuliService/ObserveChange',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveChangeRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveResponse.FromString,
                _registered_method=True)
        self.OpenApp = channel.unary_unary(
                '/sikuli.v1.SikuliService/OpenApp',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
                _registered_method=True)
        self.FocusApp = channel.unary_unary(
                '/sikuli.v1.SikuliService/FocusApp',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
                _registered_method=True)
        self.CloseApp = channel.unary_unary(
                '/sikuli.v1.SikuliService/CloseApp',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
                _registered_method=True)
        self.IsAppRunning = channel.unary_unary(
                '/sikuli.v1.SikuliService/IsAppRunning',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.IsAppRunningResponse.FromString,
                _registered_method=True)
        self.ListWindows = channel.unary_unary(
                '/sikuli.v1.SikuliService/ListWindows',
                request_serializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
                response_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ListWindowsResponse.FromString,
                _registered_method=True)


class SikuliServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Find(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindAll(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindOnScreen(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExistsOnScreen(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WaitOnScreen(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClickOnScreen(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadText(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindText(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MoveMouse(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Click(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TypeText(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Hotkey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ObserveAppear(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ObserveVanish(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ObserveChange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OpenApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FocusApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CloseApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsAppRunning(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWindows(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SikuliServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Find': grpc.unary_unary_rpc_method_handler(
                    servicer.Find,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindResponse.SerializeToString,
            ),
            'FindAll': grpc.unary_unary_rpc_method_handler(
                    servicer.FindAll,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindAllResponse.SerializeToString,
            ),
            'FindOnScreen': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOnScreen,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindOnScreenRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindResponse.SerializeToString,
            ),
            'ExistsOnScreen': grpc.unary_unary_rpc_method_handler(
                    servicer.ExistsOnScreen,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ExistsOnScreenRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ExistsOnScreenResponse.SerializeToString,
            ),
            'WaitOnScreen': grpc.unary_unary_rpc_method_handler(
                    servicer.WaitOnScreen,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.WaitOnScreenRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindResponse.SerializeToString,
            ),
            'ClickOnScreen': grpc.unary_unary_rpc_method_handler(
                    servicer.ClickOnScreen,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ClickOnScreenRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindResponse.SerializeToString,
            ),
            'ReadText': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadText,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ReadTextRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ReadTextResponse.SerializeToString,
            ),
            'FindText': grpc.unary_unary_rpc_method_handler(
                    servicer.FindText,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.FindTextRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.FindTextResponse.SerializeToString,
            ),
            'MoveMouse': grpc.unary_unary_rpc_method_handler(
                    servicer.MoveMouse,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.MoveMouseRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.SerializeToString,
            ),
            'Click': grpc.unary_unary_rpc_method_handler(
                    servicer.Click,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ClickRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.SerializeToString,
            ),
            'TypeText': grpc.unary_unary_rpc_method_handler(
                    servicer.TypeText,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.TypeTextRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.SerializeToString,
            ),
            'Hotkey': grpc.unary_unary_rpc_method_handler(
                    servicer.Hotkey,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.HotkeyRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.SerializeToString,
            ),
            'ObserveAppear': grpc.unary_unary_rpc_method_handler(
                    servicer.ObserveAppear,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveResponse.SerializeToString,
            ),
            'ObserveVanish': grpc.unary_unary_rpc_method_handler(
                    servicer.ObserveVanish,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveResponse.SerializeToString,
            ),
            'ObserveChange': grpc.unary_unary_rpc_method_handler(
                    servicer.ObserveChange,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveChangeRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ObserveResponse.SerializeToString,
            ),
            'OpenApp': grpc.unary_unary_rpc_method_handler(
                    servicer.OpenApp,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.SerializeToString,
            ),
            'FocusApp': grpc.unary_unary_rpc_method_handler(
                    servicer.FocusApp,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.SerializeToString,
            ),
            'CloseApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CloseApp,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.SerializeToString,
            ),
            'IsAppRunning': grpc.unary_unary_rpc_method_handler(
                    servicer.IsAppRunning,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.IsAppRunningResponse.SerializeToString,
            ),
            'ListWindows': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWindows,
                    request_deserializer=sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.FromString,
                    response_serializer=sikuli_dot_v1_dot_sikuli__pb2.ListWindowsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sikuli.v1.SikuliService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('sikuli.v1.SikuliService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SikuliService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Find(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/Find',
            sikuli_dot_v1_dot_sikuli__pb2.FindRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.FindResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/FindAll',
            sikuli_dot_v1_dot_sikuli__pb2.FindRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.FindAllResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindOnScreen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/FindOnScreen',
            sikuli_dot_v1_dot_sikuli__pb2.FindOnScreenRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.FindResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExistsOnScreen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/ExistsOnScreen',
            sikuli_dot_v1_dot_sikuli__pb2.ExistsOnScreenRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ExistsOnScreenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WaitOnScreen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/WaitOnScreen',
            sikuli_dot_v1_dot_sikuli__pb2.WaitOnScreenRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.FindResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ClickOnScreen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/ClickOnScreen',
            sikuli_dot_v1_dot_sikuli__pb2.ClickOnScreenRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.FindResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReadText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/ReadText',
            sikuli_dot_v1_dot_sikuli__pb2.ReadTextRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ReadTextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FindText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/FindText',
            sikuli_dot_v1_dot_sikuli__pb2.FindTextRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.FindTextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MoveMouse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/MoveMouse',
            sikuli_dot_v1_dot_sikuli__pb2.MoveMouseRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Click(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/Click',
            sikuli_dot_v1_dot_sikuli__pb2.ClickRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TypeText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/TypeText',
            sikuli_dot_v1_dot_sikuli__pb2.TypeTextRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Hotkey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/Hotkey',
            sikuli_dot_v1_dot_sikuli__pb2.HotkeyRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ObserveAppear(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/ObserveAppear',
            sikuli_dot_v1_dot_sikuli__pb2.ObserveRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ObserveResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ObserveVanish(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/ObserveVanish',
            sikuli_dot_v1_dot_sikuli__pb2.ObserveRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ObserveResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ObserveChange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/ObserveChange',
            sikuli_dot_v1_dot_sikuli__pb2.ObserveChangeRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ObserveResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OpenApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/OpenApp',
            sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FocusApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/FocusApp',
            sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CloseApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/CloseApp',
            sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ActionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsAppRunning(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/IsAppRunning',
            sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.IsAppRunningResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListWindows(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/sikuli.v1.SikuliService/ListWindows',
            sikuli_dot_v1_dot_sikuli__pb2.AppActionRequest.SerializeToString,
            sikuli_dot_v1_dot_sikuli__pb2.ListWindowsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
